****************************************************
******** LUCID data (Election Type) ****************
****************************************************
use RawData/lucid_data.dta, clear

*** TREATMENT INDICATORS
gen t_local=(strpos(treat_lowinfo,"local politics")~=0)
gen t_state=(strpos(treat_lowinfo,"state politics")~=0)
gen t_natl=(strpos(treat_lowinfo,"national politics")~=0)
label var t_local "Treat: Local Politics"
label var t_state "Treat: State Politics"
label var t_natl "Treat: National Politics"
gen all=1

gen treat_li_recycle=.
replace treat_li_recycle=1 if strpos(treat_lowinfo,"They recycle")~=0
replace treat_li_recycle=0 if strpos(treat_lowinfo,"They do not recycle")~=0
label var treat_li_recycle "Treat: They recycle (1=yes, 0=no)"

gen treat_li_informed=.
replace treat_li_informed=1 if strpos(treat_lowinfo,"they stay informed")~=0
replace treat_li_informed=0 if strpos(treat_lowinfo,"they do not stay informed")~=0
label var treat_li_informed "Treat: Stay informed about politics (1=yes, 0=no)"

gen treat_li_vote=0
replace treat_li_vote=1 if strpos(treat_lowinfo,"always vote")~=0
label var treat_li_vote "Always vote (1=yes, 0=no or omitted)"

gen treat_li_nevervote=0
replace treat_li_nevervote=1 if strpos(treat_lowinfo,"never vote")~=0
label var treat_li_nevervote "Never vote (1=yes, 0=yes or omitted)"

gen treat_li_vote_informed=treat_li_informed*treat_li_vote
label var treat_li_vote_informed "Informed X Vote (1=Informed and vote)"

gen treat_li_nevervote_informed=treat_li_informed*treat_li_nevervote
label var treat_li_nevervote_informed "Informed X Never Vote (1=Informed and never vote)"

* Drop if did not answer all outcome questions
drop if lowinfo_1==. | lowinfo_2==. | lowinfo_3==. | lowinfo_4==.
*drop if missing covariates
reg dem_raceblack dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7
drop if e(sample)==0

* Test of random assignment
gen dem_racewhite=dem_raceblack==0 & dem_raceother==0
//Treat Hispanic as separate, but categorize as "other" if Hisp + other non-white racial ID
gen dem_racehisp=dem_hisp
//if ID as black or other + hispanic, set to "other"
replace dem_raceblack=0 if dem_racehisp==1 & (dem_raceblack==1 | dem_raceother==1)
replace dem_racewhite=0 if dem_racehisp==1 & (dem_raceblack==1 | dem_raceother==1)
replace dem_racehisp=0 if dem_racehisp==1 & (dem_raceblack==1 | dem_raceother==1)
replace dem_raceother=1 if dem_racehisp==1 & (dem_raceblack==1 | dem_raceother==1)

//replace white and black = 0 if Hispanic
replace dem_racewhite = 0 if dem_racehisp==1
replace dem_raceblack = 0 if dem_racehisp==1
 
label var dem_raceother "Other Race/Multiple/Refused = 1"
label var dem_racewhite "White = 1"
label var dem_raceblack "Black = 1"
label var dem_racehisp  "Hispanic = 1"
label var dem_age "Age (in years)"
label var dem_female "Female=1"
label var dem_pid7 "Party ID (-3=S. Dem; 3=S. Rep)"
label var dem_interest "Political Interest (1-5)"
label var dem_education "Education (1=No HS; 8=PhD+)"
label var dem_hhincome "Income (1-24; 25 = Refused)"
label var dem_hhincomemiss "Income Missing"

//BALANCE TEST         
gen condition  = treat_li_vote +treat_li_nevervote*2 + t_local*4 + t_state*8 + treat_li_recycle*16 + treat_li_informed*32
mlogit condition dem_raceblack dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7

* Outcome variables
label var lowinfo_1 "Outcome: Overall Impression Positive (1-7)"
label var lowinfo_2 "Outcome: Person Responsible (1-7)"
label var lowinfo_3 "Outcome: Respect Person (1-7)"
label var lowinfo_4 "Outcome: Good Citizen (1-7)"

gen dv=""
gen sample=""
gen out_vote_ni_info_not=.
label var out_vote_ni_info_not "No Vote Info, Not Informed"
gen out_vote_ni_info_yes=.
label var out_vote_ni_info_yes "No Vote Info, Informed"
gen out_vote_no_info_not=.
label var out_vote_no_info_not "Don't Vote, Not Informed"
gen out_vote_no_info_yes=.
label var out_vote_no_info_yes "Don't Vote, Informed"
gen out_vote_yes_info_not=.
label var out_vote_yes_info_not "Always Vote, Not Informed"
gen out_vote_yes_info_yes=.
label var out_vote_yes_info_yes "Always Vote, Informed"
gen mfx_b_vote_given_info_yes=.

label var mfx_b_vote_given_info_yes "Marginal effect of voting given informed"
gen mfx_b_vote_given_info_no=.
label var mfx_b_vote_given_info_no "Marginal effect of voting given not informed"
gen mfx_p_vote_given_info_yes=.
gen mfx_p_vote_given_info_no=.

gen mfx_b_diff_vote_given_info_yesno=.
label var mfx_b_diff_vote_given_info_yesno "DID: Marginal effect of voting vs not given informed vs not"
gen mfx_p_diff_vote_given_info_yesno=.
label var mfx_p_diff_vote_given_info_yesno "DID: P-value"

alpha lowinfo_1 lowinfo_2 lowinfo_3 lowinfo_4
//gen dvscale=((lowinfo_1+lowinfo_2+lowinfo_3+lowinfo_4)/4 )-4
gen dvscale=((lowinfo_1+lowinfo_2+lowinfo_3)/3 )-4
label var dvscale "Social evaluations scale (3 items, -3 to 3)"

***SUMMARY STATS
outsum dem_racewhite dem_raceblack dem_racehisp dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7 using "Tables/TableA1_summarystats", bracket append ctitle(Lucid)

*********REGRESSIONS
regress dvscale treat_li_recycle treat_li_informed treat_li_vote treat_li_nevervote  treat_li_vote_informed treat_li_nevervote_informed t_local t_state dem_raceblack dem_racehisp dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7, robust
est store base
sum dvscale 
local sd=r(sd)

lincom treat_li_vote-treat_li_nevervote
local v_ninfo=r(estimate)
lincom (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
local v_info=r(estimate)

test treat_li_vote_informed==treat_li_nevervote_informed
outreg2 using "Tables/TableA4_Lucid.out", addstat("Standard Deviation of Outcome",`sd',"Voting FX (Not Informed)",`v_ninfo',"Voting FX (Informed)",`v_info',"Difference in FX (p-value)",r(p)) se bracket replace rdec(3) adec(3)
//grab estimates to graph
est restore base
lincomest treat_li_vote-treat_li_nevervote
est store all_ninfo
est restore base
lincomest (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
est store all_info

foreach levelrest in "t_natl" "t_state" "t_local" {
regress dvscale treat_li_recycle treat_li_informed treat_li_vote treat_li_nevervote  treat_li_vote_informed treat_li_nevervote_informed  dem_raceblack dem_racehisp dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7 if `levelrest'==1, robust
est store base
sum dvscale  if `levelrest'==1
local sd=r(sd)

lincom treat_li_vote-treat_li_nevervote
local v_ninfo=r(estimate)
lincom (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
local v_info=r(estimate)
test treat_li_vote_informed==treat_li_nevervote_informed
outreg2 using "Tables/TableA4_Lucid.out", addstat("Standard Deviation of Outcome",`sd',"Voting FX (Not Informed)",`v_ninfo',"Voting FX (Informed)",`v_info',"Difference in FX (p-value)",r(p)) se bracket append rdec(3) adec(3)

//grab estimates to graph
est restore base
lincomest treat_li_vote-treat_li_nevervote
est store `levelrest'_ninfo
est restore base
lincomest (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
est store `levelrest'_info
}

*** FIGURE 3
coefplot (all_info, rename((1) = "Informed (All)" )  \ all_ninfo, rename((1) = "Not Informed (All)" ) \ t_natl_info, rename((1) = "Informed (National)" )\ t_natl_ninfo, rename((1) = "Not Informed (National)" ) \ t_state_info, rename((1) = "Informed (State)" ) \ t_state_ninfo, rename((1) = "Not Informed (State)" )\ t_local_info, rename((1) = "Informed (Local)")\ t_local_ninfo, rename((1) = "Not Informed (Local)" )   msymbol(O) connect(none) msize(medium) mcolor(black) ciopts(lcolor(black) lwidth(thin)) label(Coefs)) , vertical legend(off) level(95) coeflabels(,wrap(10)) title("Figure 3: Information and Voting across Election Types",  size(med)) ytitle("Effect of Always Rather than Never Voting",  size(medsmall)) note("Note: Markers indicate estimated effect of target being described as always, rather than never, voting." "Outcome measure is evaluation scale, which ranges from -3 to 3." "Whiskers indicate 95% confidence intervals.",  size(small) span)   graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) ylabel(0 1 2) yline(0, lc(black) lw(thin) ) xscale(lw(none)) xlabel(, labsize(small)) 
graph export "Figures/figure_3.tif", as(tif) width(4000) replace
//graph export "Figures\figure_3.pdf", as(pdf) replace

//ROBUSTNESS
//no covariates
foreach levelrest in "all" "t_natl" "t_state" "t_local" {
regress dvscale treat_li_recycle treat_li_informed treat_li_vote treat_li_nevervote  treat_li_vote_informed treat_li_nevervote_informed t_local t_state if `levelrest'==1, robust
sum dvscale  if `levelrest'==1
local sd=r(sd)
lincom treat_li_vote-treat_li_nevervote
local v_ninfo=r(estimate)
lincom (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
local v_info=r(estimate)
test treat_li_vote_informed==treat_li_nevervote_informed
outreg2 using "Tables/TableA4_Lucid.out", addstat("Standard Deviation of Outcome",`sd',"Voting FX (Not Informed)",`v_ninfo',"Voting FX (Informed)",`v_info',"Difference in FX (p-value)",r(p)) se bracket append rdec(3) adec(3)
}

//covariates + Weights
foreach levelrest in "all" "t_natl" "t_state" "t_local" {
regress dvscale treat_li_recycle treat_li_informed treat_li_vote treat_li_nevervote  treat_li_vote_informed treat_li_nevervote_informed t_local t_state dem_raceblack dem_racehisp dem_raceother dem_age dem_female dem_education dem_hhincome dem_hhincomemiss dem_interest dem_pid7 if `levelrest'==1 [aw=weight], robust
sum dvscale  if `levelrest'==1
local sd=r(sd)
lincom treat_li_vote-treat_li_nevervote
local v_ninfo=r(estimate)
lincom (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
local v_info=r(estimate)
test treat_li_vote_informed==treat_li_nevervote_informed
outreg2 using "Tables/TableA4_Lucid.out", addstat("Standard Deviation of Outcome",`sd',"Voting FX (Not Informed)",`v_ninfo',"Voting FX (Informed)",`v_info',"Difference in FX (p-value)",r(p)) se bracket append rdec(3) adec(3)  ctitle("Weights")
}

//no covariates + Weights
foreach levelrest in "all" "t_natl" "t_state" "t_local" {
regress dvscale treat_li_recycle treat_li_informed treat_li_vote treat_li_nevervote  treat_li_vote_informed treat_li_nevervote_informed t_local t_state if `levelrest'==1 [aw=weight], robust
sum dvscale  if `levelrest'==1
local sd=r(sd)
lincom treat_li_vote-treat_li_nevervote
local v_ninfo=r(estimate)
lincom (treat_li_vote+treat_li_vote_informed)-(treat_li_nevervote+treat_li_nevervote_informed)
local v_info=r(estimate)
test treat_li_vote_informed==treat_li_nevervote_informed
outreg2 using "Tables/TableA4_Lucid.out", addstat("Standard Deviation of Outcome",`sd',"Voting FX (Not Informed)",`v_ninfo',"Voting FX (Informed)",`v_info',"Difference in FX (p-value)",r(p)) se bracket append rdec(3) adec(3) ctitle("Weights")
}
